/***************************************************************************
*   Copyright (C) 2004 by Thomas Fischer                                  *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qdragobject.h>
#include <qevent.h>
#include <qapplication.h>
#include <qclipboard.h>

#include <klocale.h>
#include <kbibtex_part.h>

#include "kbibtexlistview.h"

KBibTeXListView::KBibTeXListView( KBibTeXPart *kbibtexpart, QWidget *parent, const char *name )
        : KListView( parent, name )
{
    addColumn( i18n( "Type" ) );
    setColumnWidthMode( 0, QListView::Manual );
    addColumn( i18n( "Id" ) );
    setColumnWidthMode( 1, QListView::Manual );
    addColumn( i18n( "Title" ) );
    setColumnWidthMode( 2, QListView::Manual );
    addColumn( i18n( "Author" ) );
    setColumnWidthMode( 3, QListView::Manual );
    addColumn( i18n( "Year" ) );
    setColumnWidthMode( 4, QListView::Manual );
    setAllColumnsShowFocus( true );
    setSorting( 100 );
    setShowSortIndicator( true );

    setAcceptDrops( true );

    //this->parent = dynamic_cast<KBibTeXPart*>( parent );
    this->kbibtexpart = kbibtexpart;

    connect( this, SIGNAL( mouseButtonPressed( int, QListViewItem*, const QPoint&, int ) ),
             this, SLOT( slotMouseButtonPressed( int, QListViewItem*, const QPoint&, int ) ) );
}

KBibTeXListView::~KBibTeXListView()
{}

void KBibTeXListView::resizeEvent ( QResizeEvent * e )
{
    int width = e->size().width() - 32;

    setColumnWidth( 0, width / 13 );
    setColumnWidth( 1, width * 2 / 13 );
    setColumnWidth( 2, width * 5 / 13 );
    setColumnWidth( 3, width * 4 / 13 );
    setColumnWidth( 4, width / 13 );

    KListView::resizeEvent( e );
}

void KBibTeXListView::contentsDragEnterEvent( QDragEnterEvent *e )
{
    qDebug( "dragEnterEvent" );
    //e->accept( QTextDrag::canDecode(e) );
    e->accept( true );
}

void KBibTeXListView::contentsDropEvent( QDropEvent *e )
{
    QString text;
    QTextDrag::decode( e, text );

    qDebug( "drag text: %s", text.latin1() );
}

void KBibTeXListView::slotMouseButtonPressed( int button, QListViewItem* after, const QPoint& p, int col )
{
    switch ( button )
    {
    case Qt::MidButton:
        {
            QString clipText( QApplication::clipboard() ->text( QClipboard::Selection ) );
            if ( kbibtexpart != NULL )
                kbibtexpart->insertText( clipText );
            break;
        }
    default: break;
    }
}

#include "kbibtexlistview.moc"
